@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2015-10-20'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-12-18'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -72,12 +72,12 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.04 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2015-10-20.
+This document describes version 0.05 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2015-12-18.
 
 =head1 FUNCTIONS
 
 
-=head2 call_lcpan_script(%args) -> [status, msg, result, meta]
+=head2 call_lcpan_script(%args) -> any
 
 "Call" lcpan script.
 
@@ -91,15 +91,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
 Return value:  (any)
 
 =head1 HOMEPAGE
